# rpmbuild -ba THIS.SPEC --target "$(uname -m)"
# 
## To rebuild only userland-package: 
#
# rpmbuild -ba THIS.SPEC --without modules
#
## To rebuild only kernel modules against currently running fedora kernel 
#
# rpmbuild -ba THIS.SPEC --without userland --target "$(uname -m)" 
#
## To rebuild only kernel modules against a kernel where /lib/modules/$(uname -r)/build points
##  to the build-sources (e.g. self compiled, fedora-kernel without kernel-devel package)
#
# rpmbuild -ba THIS.SPEC --without userland --target "$(uname -m)" --define "ksrc /lib/modules/$(uname -r)/build" 
#
#### End of Building instructions.

%{?ksrc: 	%{!?kernel:    %{expand: %%define kernel %(cd "%{ksrc}" &> /dev/null && echo "$(cat Makefile 2>/dev/null && echo $'\n'kernelhelper-rel:$'\n'$'\t'@echo \$\(KERNELRELEASE\)$'\n')" 2>/dev/null | make -f - kernelhelper-rel 2>/dev/null || echo "custom" ) }}}
%{!?kernel:             %{expand: %%define kernel %(uname -r)}}

%define short_name qcusb
%define real_name qc-usb
%define real_release 1

%define _libmoddir /lib/modules
%define moduledir /kernel/drivers/usb/qc-usb
%define modules quickcam.ko

Summary: Linux QuickCam USB Drivers
Name: kernel-module-%{short_name}-%{kernel}
Version: 0.6.3
Release: 2.SL4x
License: GPL
Group: System Environment/Kernel
URL: http://www.ee.oulu.fi/~tuukkat/quickcam/quickcam.html
Packager: Troy Dawson <dawson@fnal.gov>
Source: http://www.ee.oulu.fi/~tuukkat/quickcam/qc-usb-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{kernel}-root
Requires: qcset
%if 0%{!?ksrc:1}
Requires:	 /boot/vmlinuz-%{kernel}
%endif
%if 0%{!?_without_modules:1}
%if 0%{!?ksrc:1}
BuildRequires:  kernel-devel = %{kernel}
%endif
%endif
Obsoletes: %{real_name}, kernel-%{real_name}
Provides: %{short_name}, %{real_name}, kernel-%{real_name}
Provides: kernel-module-%{short_name}, kernel-module-%{real_name}

%description
Linux QuickCam USB drivers.

These drivers are built for kernel %{kernel}
and architecture %{_target_cpu}.
They might work with newer/older kernels.

%package -n qcset
Summary: Linux QuickCam USB utilities
Group: System Environment/Base

%description -n qcset
Utility to configure the QuickCam USB settings.

%prep
%setup -n %{real_name}-%{version}

%build
%{__rm} -rf %{buildroot}
### Build Everything, can't really seperate this
echo -e "\nDriver version: %{version}\nKernel version: %{kernel}\n"
%{__make} %{?_smp_mflags} clean all MODULE_DIR="%{_libmoddir}/%{kernel}"

%install
%if 0%{!?_without_modules:1}
### Install Modules.
%{__install} -d -m0755 %{buildroot}%{_libmoddir}/%{kernel}%{moduledir}
%{__install} -m0644 %{modules} %{buildroot}%{_libmoddir}/%{kernel}%{moduledir}
%endif #!?_without_modules:1

%if 0%{!?_without_userland:1}
### Install Utility.
%{__install} -d -m0755 %{buildroot}%{_bindir}
%{__install} -m0755 qcset %{buildroot}%{_bindir}
%endif	# 0%!?_without_userland:1

%post
/sbin/depmod -ae %{kernel} || :

%postun
/sbin/depmod -ae %{kernel} || :


%clean
%{__rm} -rf %{buildroot}

%if 0%{!?_without_modules:1}
%files
%defattr(-, root, root, 0755)
%{_libmoddir}/%{kernel}%{moduledir}/
%endif #!?_without_modules:1

%if 0%{!?_without_userland:1}
%files -n qcset
%defattr(-, root, root, 0755)
%doc APPLICATIONS COPYING FAQ README README.qce TODO qcweb-info.txt
%{_bindir}/qcset
%endif	# 0%!?_without_userland:1

%changelog
* Tue Feb 01 2005 Troy Dawson <dawson@fnal.gov> - 0.6.3-1.SL4
- Updated it to 0.6.3
- changed spec stuff to be in line with livna format

* Tue Feb 01 2005 Troy Dawson <dawson@fnal.gov> - 0.6.2-1.tjd
- Changed it to the kernel-module-<name>-<kernel> naming

* Mon Jan 24 2005 Troy Dawson <dawson@fnal.gov> - 0.6.2-1
- Moved it to 0.6.2, and tweeked a building problem

* Thu Mar 11 2004 Dag Wieers <dag@wieers.com> - 0.5.1-1
- Fixed the longstanding smp kernel bug. (Bert de Bruijn)

* Wed Sep 17 2003 Dag Wieers <dag@wieers.com> - 0.5.1-0
- User contributed package. (Bert de Bruijn)

* Tue Sep 16 2003 Bert de Bruijn <bert@debruijn.be> - 0.5.1-0
- Initial package.
